Examples
===========

The following section provides a set of examples.

.. note::

   zhinst-qcodes is based on zhinst-toolkit. Meaning it has the same device
   specific functions and structure. Please take a look at the examples in the
   `zhinst-toolkit examples <https://docs.zhinst.com/zhinst-toolkit/en/latest/examples/index.html>`_
   for a more extensive list of examples.

.. toctree::
   :caption: Devices
   :maxdepth: 2

   hf2
   daq_module
   scope_module
   sweeper_module
   shfqa_qubit_readout_measurement
   shfqa_qubit_readout_weights
   shfqa_sweeper
   shfsg_rabi

